/* LTA API
 *
 * (c) Copyright 2016, TERMEX LTD.
 * This file is provided as is (no warranties).
 */
#pragma library Lta

// Output pin.
const Pin:
{
    pin1 = 0,
    pin2 = 1
}

// Pull up, pull down
const Pupd:
{
    no_pull = 0,
    pull_up,
    pull_down
}

// Interrupt trigger.
const Trigger:
{
    int_rising = 0,
    int_falling,
    int_rising_falling
}

// System events.
const Event:
{
    ev_timer = 0,
    ev_interrupt,
    ev_result,
    ev_data
}

// Type of result.
const Result:
{
    res_temp = 0,
    res_resist
}

// Some math statistics.
const Stats:
{
    st_dt = 0,
    st_min,
    st_max,
    st_avg,
    st_slope
}

//
const timer_tick = 100; // ms


// Returns version of the device firmware/hardware.
// The version consist of four numbers: XX.YY.ZZ-HH
// XX - device's functionality.
// YY - firmware's improvement.
// ZZ - bug fixes.
// HH - hardware's version.
//
// It is packed as unsigned 32-bit number: 0xXXYYZZHH
native version() = -56;

// Copy device's serial number to the string.
// Returns the number of copied charachters (up to 8).
native serial_number(string[], maxlength=sizeof string, bool:pack=true) = -57;

// Returns true if the device has 2 temperature channel.
native bool:has_2() = -58;

// Returns true if the device has bluetooth module.
native bool:has_bluetooth() = -59;

// Returns true if the device has digital I/O capability.
native bool:has_dio() = -60;

// Returns true if the device is connected to a usb port and
// usb is in configured state.
native bool:is_usb_configured() = -61;

// Returns true if external power suply is connected.
native bool:has_external_power() = -62;

// Returns the sample period in seconds.
// The value is in range [1, 3600]s.
native sample_period() = -63;

// Returns the auto shutdown period in minutes.
// The value is in range [0, 64800].
// 0 means auto shutdown is off.
// 64800 matches 45 days.
native shutdown_period() = -64;

// Returns the logging period in sample period.
// The value is in range [1, 3600]
native log_period() = -65;

// Returns true if logging is on.
native bool:is_logging() = -66;

// The function enables or disables logging.
native enable_logging(bool:v) = -67;

// Returns true if bluetooth module is on.
native bool:is_bluetooth_enabled() = -68;

// The function enables or disables bluetooth module.
native enable_bluetooth(bool:v) = -69;

// Returns the number of eeprom cells available for
// using in the script.
native bkpmem_count() = -70;

// Returns the value of cpecified eeprom cell.
// The cells index should be in range [0, bkpmem_count-1].
// Returns 0 if index is not in valid range.
native read_bkpmem(idx) = -71;

// Writes the value to the cpecified eeprom cell.
// The cells index should be in range [0, bkpmem_count-1].
// Does nothing if index is not in valid range.
native write_bkpmem(idx, v) = -72;

// The group of Float:get_xx functions returns 0 if
// invalid channel number is cpecified.
// The channel number n should be in range [0, 1].

// Returns the temperature [celsius] or resistance [ohm].
native Float:get_result(n, Result:r=res_temp) = -73;

// Returns ...?
native Float:get_tempstats(n, Stats:s) = -74;

// Returns in coef array the coefficients used for temperature calculate.
// Coefficients order is [R0, A, B, C] for Callendar Van Dusen equation.
native get_tempcoef(n, Float:coef[4]) = -75;

// Returns the parameters of moving average filter.
// size - the size of filter buffer.
// level - the filtering level.
native get_filterparams(n, &size, &Float:level) = -76;

// Initializes specified output pin.
native init_out_pin(Pin:p) = -77;

// Deinitializes specified output pin in low power state.
native deinit_out_pin(Pin:p) = -78;

// Writes the value to the cpecified output pin.
native write_out_pin(Pin:p, v) = -79;

// Toggle cpecified output pin.
native toggle_out_pin(Pin:p) = -80;

// Initializes input pin with cpecified pull up.
native init_in_pin(Pupd:pull) = -81;

// Deinitializes input pin in low power state.
native deinit_in_pin() = -82;

// Returns input pin state.
native read_in_pin() = -83;

// Configures interrupt trigger.
native in_pin_interrupt_cfg(Trigger:edge) = -84;

// Enables or disables interrupt.
native in_pin_interrupt_enable(bool:v) = -85;

// Starts timer (singleshot or periodic) for cpecified time.
// Timer stops if ticks = 0.
native set_timer(ticks, bool:singleshot=true) = -86;

// Returns the number of CPU cycles from reset.
//
// Remark.
//   While using battery power, the CPU clock is about 1 MHz.
//   And one CPU cycle is ~1 microsecond.
//   While using external power (e.g. USB), the CPU clock is 12 MHz.
//   And one CPU cycle is 1/12=0.08(3) microseconds.
//
native cpucycles() = -87;

// The function waits when specified event occurs.
native waitfor(Event: e) = -88;

// Enables or disables enqueue for specified event.
native enable_event_enqueue(Event:e, bool:v) = -89;

// Pops and returns an event from event queue.
native Event:queue_pop() = -90;

// Pushes specified event to the event queue.
// Returns true if success.
native bool:queue_push(Event: e) = -91;

// Stops the script execution for spicified time.
stock pause(ticks)
{
    if ( ticks )
    {
        set_timer(ticks);
        waitfor(ev_timer);
    }
}

